@@ -1,12 +1,11 @@
-from fastapi import Depends, HTTPException
+from fastapi import Security, HTTPException
 from typing import Dict, Any, List, Union
 from pydantic import BaseModel
 from typing import Optional
-from .user import User
-from .helpers import get_current_user
+from .security import User, process_user_claim
 from .app import app
 from ..networking import ip, get_interface_info, create_interface, add_namespace, get_namespace_info, del_namespace
-from ..exceptions import InterfaceNotFound, NamespaceNotFound
+from ..helpers.exceptions import InterfaceNotFound, NamespaceNotFound
 
 class NewInterface(BaseModel):
 	iftype: str
@@ -16,7 +15,7 @@ class NewInterface(BaseModel):
 	state: Optional[str] = "up"
 
 @app.get("/networking/interface/{ifname}", tags=["networking"])
-def get_network_interface_info(ifname :str, current_user: User = Depends(get_current_user)) -> List[Dict[str, Union[int, None, str]]]:
+def get_network_interface_info(ifname :str, current_user: User = Security(process_user_claim, scopes=["networking*"])) -> List[Dict[str, Union[int, None, str]]]:
 	"""
 	Returns networking information for the given interface.
 	The result will be a list of addresses:
@@ -35,7 +34,7 @@ def get_network_interface_info(ifname :str, current_user: User = Depends(get_cur
 		raise HTTPException(status_code=404, detail="Interface not found")
 
 @app.put("/networking/interface/{ifname}", tags=["networking"])
-def create_new_interface(ifname :str, info :NewInterface, current_user: User = Depends(get_current_user)) -> List[Dict[str, Union[int, None, str]]]:
+def create_new_interface(ifname :str, info :NewInterface, current_user: User = Security(process_user_claim, scopes=["networking*"])) -> List[Dict[str, Union[int, None, str]]]:
 	"""
 	This API can be used to create interfaces
 	"""
@@ -47,7 +46,7 @@ def create_new_interface(ifname :str, info :NewInterface, current_user: User = D
 	return list(get_interface_info(ifname))
 
 @app.delete("/networking/interface/{ifname}", tags=["networking"])
-def delete_interface(ifname :str, current_user: User = Depends(get_current_user)) -> List[Dict[str, Union[int, None, str]]]:
+def delete_interface(ifname :str, current_user: User = Security(process_user_claim, scopes=["networking*"])) -> List[Dict[str, Union[int, None, str]]]:
 	"""
 	This API can be used to delete interfaces
 	"""
@@ -62,7 +61,7 @@ def delete_interface(ifname :str, current_user: User = Depends(get_current_user)
 		return []
 
 @app.put("/networking/namespace/{name}", tags=["networking"])
-def create_new_namespace(name :str, current_user: User = Depends(get_current_user)) -> Dict[str, Any]:
+def create_new_namespace(name :str, current_user: User = Security(process_user_claim, scopes=["networking*"])) -> Dict[str, Any]:
 	"""
 	This API can be used to create namespaces.
 	"""
@@ -71,7 +70,7 @@ def create_new_namespace(name :str, current_user: User = Depends(get_current_use
 	return get_namespace_info(name)
 
 @app.delete("/networking/namespace/{name}", tags=["networking"])
-def delete_namespace(name :str, current_user: User = Depends(get_current_user)) -> Dict[str, Any]:
+def delete_namespace(name :str, current_user: User = Security(process_user_claim, scopes=["networking*"])) -> Dict[str, Any]:
 	"""
 	This API can be used to delete namespaces.
 	"""
@@ -83,14 +82,14 @@ def delete_namespace(name :str, current_user: User = Depends(get_current_user))
 		return {}
 
 @app.patch("/networking/interface/{name}/connect/{master}", tags=["networking"])
-def set_master_on_interface(name :str, master :str, current_user: User = Depends(get_current_user)) -> bool:
+def set_master_on_interface(name :str, master :str, current_user: User = Security(process_user_claim, scopes=["networking*"])) -> bool:
 	"""
 	This API endpoint can be used to set a `master` on a given interface name.
 	"""
 	return bool(ip.link(f"set dev {name} master {master}").exit_code == 0)
 
 @app.patch("/networking/interface/{name}/move/{namespace}", tags=["networking"])
-def move_interface_to_namespace(name :str, namespace :str, current_user: User = Depends(get_current_user)) -> bool:
+def move_interface_to_namespace(name :str, namespace :str, current_user: User = Security(process_user_claim, scopes=["networking*"])) -> bool:
 	"""
 	This API endpoint can be used to move a certain interface into a namespace.
 	This endpoint does not create the namespace however. Use `/networking/namespace/{name}`
