@@ -2,13 +2,12 @@ import json
 import pathlib
 from typing import Optional, Dict, Any, List, Union
 from pydantic import BaseModel
-from fastapi import Depends, HTTPException
+from fastapi import Security, HTTPException
 from .app import app
-from .helpers import get_current_user
-from .user import User
+from .security import User, process_user_claim
 from ..qemu import write_qemu_service_file, create_qemu_string, verify_qemu_resources, qemu_img
-from ..dupedict import DupeDict, JSON
-from ..syscalls import SysCommand
+from ..helpers.dupedict import DupeDict, JSON
+from ..helpers.syscalls import SysCommand
 
 class NewVirtualMachine(BaseModel):
 	namespace: Optional[str] = None
@@ -37,7 +36,7 @@ class ResourceLocations(BaseModel):
 	run_as: str = 'root'
 
 @app.put("/qemu/machine/{name}", tags=["qemu"])
-def create_machine_configuration(name :str, info :NewVirtualMachine, current_user: User = Depends(get_current_user)) -> Dict[str, Any]:
+def create_machine_configuration(name :str, info :NewVirtualMachine, current_user: User = Security(process_user_claim, scopes=["qemu*"])) -> Dict[str, Any]:
 	"""
 	This API can be used to create new virtual machine configuration.
 	This API endpoint will create harddrive resources specified in `--harddrives`.
@@ -147,7 +146,7 @@ def create_machine_configuration(name :str, info :NewVirtualMachine, current_use
 
 
 @app.put("/qemu/machine/{name}/string", tags=["qemu"])
-def create_qemu_string_from_struct(name :str, info :NewVirtualMachine, current_user: User = Depends(get_current_user)) -> str:
+def create_qemu_string_from_struct(name :str, info :NewVirtualMachine, current_user: User = Security(process_user_claim, scopes=["qemu*"])) -> str:
 	"""
 	This API can be used to create new virtual machines.
 	This API will not create machine resources, but simply returns a QEMU string that can be called.
@@ -180,7 +179,7 @@ def create_qemu_string_from_struct(name :str, info :NewVirtualMachine, current_u
 	return create_qemu_string(name, info.namespace, base_hardware, pcie_buses, pcie_root_ports, pcie_slave_buses, pcie_slave_devices)
 
 @app.post("/qemu/machine/{name}/start", tags=["qemu"])
-def start_qemu_machine(name :str, locations :ResourceLocations, current_user: User = Depends(get_current_user)) -> None:
+def start_qemu_machine(name :str, locations :ResourceLocations, current_user: User = Security(process_user_claim, scopes=["qemu*"])) -> None:
 	"""
 	This endpoint starts a qemu instance using a previously created service file with the given name.
 	"""
@@ -191,7 +190,7 @@ def start_qemu_machine(name :str, locations :ResourceLocations, current_user: Us
 		SysCommand(f"systemctl --user start {name}.service")
 
 @app.post("/qemu/machine/{name}/stop", tags=["qemu"])
-def stop_qemu_machine(name :str, locations :ResourceLocations, current_user: User = Depends(get_current_user)) -> None:
+def stop_qemu_machine(name :str, locations :ResourceLocations, current_user: User = Security(process_user_claim, scopes=["qemu*"])) -> None:
 	"""
 	This endpoint stops a qemu instance using a previously created service file with the given name.
 	"""
@@ -202,7 +201,7 @@ def stop_qemu_machine(name :str, locations :ResourceLocations, current_user: Use
 		SysCommand(f"systemctl --user stop {name}.service")
 
 @app.get("/qemu/machine/{name}/status", tags=["qemu"])
-def status_qemu_machine(name :str, current_user: User = Depends(get_current_user)) -> Dict[str, str]:
+def status_qemu_machine(name :str, current_user: User = Security(process_user_claim, scopes=["qemu*"])) -> Dict[str, str]:
 	"""
 	This endpoint gets the service status of the machine.
 	If the machine is missing or dead, it will return inactive.
@@ -211,7 +210,7 @@ def status_qemu_machine(name :str, current_user: User = Depends(get_current_user
 	return {'status': str(SysCommand(f"systemctl -o json is-active postgresql {name}.service").decode())}
 
 @app.patch("/qemu/machine/{name}/snapshot", tags=["qemu"])
-def snapshot_qemu_machine(name :str, current_user: User = Depends(get_current_user)) -> None:
+def snapshot_qemu_machine(name :str, current_user: User = Security(process_user_claim, scopes=["qemu*"])) -> None:
 	"""
 	This endpoint enables you to take a snapshot of a machine's current state.
 	If it's running the memory and all devices will be snapshotted using the builtin qemu snapshot tool.
@@ -222,7 +221,7 @@ def snapshot_qemu_machine(name :str, current_user: User = Depends(get_current_us
 	raise HTTPException(status_code=501, detail="Not yet implemented")
 
 @app.patch("/qemu/machine/{name}/migrate", tags=["qemu"])
-def migrate_qemu_machine(name :str, current_user: User = Depends(get_current_user)) -> None:
+def migrate_qemu_machine(name :str, current_user: User = Security(process_user_claim, scopes=["qemu*"])) -> None:
 	"""
 	This endpoint enables you to migrate the machine to a different cluster.
 	"""
@@ -230,7 +229,7 @@ def migrate_qemu_machine(name :str, current_user: User = Depends(get_current_use
 	raise HTTPException(status_code=501, detail="Not yet implemented")
 
 @app.post("/qemu/machine/{name}/export", tags=["qemu"])
-def export_qemu_machine(name :str, current_user: User = Depends(get_current_user)) -> None:
+def export_qemu_machine(name :str, current_user: User = Security(process_user_claim, scopes=["qemu*"])) -> None:
 	"""
 	This endpoint enables you to export either the configuration or to do a full export including devices.
 	"""
